<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="5">
                    <el-col :span="5">
                        <el-form-item label="应用名称">
                            <el-input placeholder="请输入应用名称" v-model="searchForm[`app_Name_`]"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="牵头单位">
                            <el-input placeholder="请输入单位名称" v-model="searchForm[`qt_Unit_Name_`]"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="所属领域">
                            <el-input placeholder="请输入所属领域" v-model="searchForm[`field_Group_`]"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="是否进入一本账">
                            <el-select v-model="searchForm[`is_Entry_Bill_`]" placeholder="请选择">
                                <el-option v-for="item in searchOptions" :key="item.value" :label="item.label"
                                    :value="item.value">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel">
                <div style="margin-bottom: 10px" ref="btnPanel"></div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }" @selection-change="handleSelectionChange">
                        <el-table-column type="index" width="100" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="appName" show-overflow-tooltip align="center" label="应用名称">
                        </el-table-column>
                        <el-table-column prop="fieldGroup" show-overflow-tooltip align="center" label="所属领域">
                        </el-table-column>
                        <el-table-column prop="runway" show-overflow-tooltip align="center" label="所属跑道">
                            <!-- <template v-slot="{ row }">
                                {{ getDictName('ggbb_sspd', row.runway) }}
                            </template> -->
                        </el-table-column>
                        <el-table-column prop="qtUnitName" show-overflow-tooltip align="center" label="牵头单位">
                        </el-table-column>
                        <el-table-column prop="isEntryBill" show-overflow-tooltip align="center" label="是否进入一本账">
                            <template v-slot="{ row }">
                                <el-tag v-if="row.isEntryBill == 1" type="success">是</el-tag>
                                <el-tag v-else type="warning">否</el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip width="180" align="center" fixed="right" label="操作">
                            <template v-slot="{ row }">
                                <template>
                                    <span>
                                        <!-- <el-link icon="el-icon-s-check" type="primary" :underline="false"
                                            class="cloumn-btn">
                                            上报
                                        </el-link> -->
                                        <el-link v-if="row.isEntryBill == 1" icon="el-icon-view" type="primary"
                                            :underline="false" class="cloumn-btn" @click="toEditPage('detail', row)">
                                            详情
                                        </el-link>
                                        <el-link v-else icon="el-icon-edit" type="primary" :underline="false"
                                            class="cloumn-btn" @click="toEditPage('edit', row)">
                                            编辑
                                        </el-link>

                                        <!-- <el-link v-if="row.isEntryBill == 1" icon="el-icon-refresh-left" type="danger"
                                            :underline="false" class="cloumn-btn withdraw" @click="clickReport(row)">
                                            撤回
                                        </el-link> -->
                                    </span>
                                </template>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import apiList from '@/api/digitalApi/appApi'
const portal = window.context.portal
export default {
    name: 'DGAppBaseInfoSearch',
    components: {
        pagination
    },
    mixins: [TableMixin],
    data() {
        return {
            searchOptions: [
                {label: '是', value:'1'},
                {label: '否', value:'0'}
            ],
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            searchForm: {
            }, // 顶部搜索对象
            markLoading: false,
            tableData: [
                {
                    estigationName: '测试',
                    scoringDate: "2024-02-20",
                    status: 0
                }
            ],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: '', // 字段名
                        relation: 'AND',
                        value: {},
                    },{
                        group: 'main',
                        operation: 'NOTNULL',
                        parentGroup: '',
                        property: 'list_Code_', // 字段名
                        relation: 'AND',
                        value: "",
                    },
                ],
            },
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            deleteIds: '', // 是否选中列表解锁删除按钮

        }
    },
    created() {
        this.getData(this.params)
    },
    methods: {
        getData(data) {
            this.tableLoading = true
            apiList.gteBaseInfo(data, res => {
                if (res) {
                    this.pageResult.total = res.total
                    this.tableLoading = false
                    this.tableData = res.rows
                }
            })
        },
        toEditPage(type, row) {
            console.log(row);
            this.$router.push({
                path: '/platLayout/saveOrUpdatePage',
                query: {
                    id: row.id,
                    type: type,
                    key: 'basic',
                },
            })
        },
        handleSearch(page) {
            this.tableLoading = true
            let data = JSON.parse(JSON.stringify(this.params))
            let obj = JSON.parse(JSON.stringify(this.searchForm))
            let querys = []
            for (let i in obj) {
                if (obj[i]) {
                    querys.push({
                        group: 'main',
                        operation:
                            i == 'app_Name_' || i == 'qt_Unit_Name_' ? 'LIKE' : 'EQUAL',
                        parentGroup: '',
                        property: i,
                        relation: 'AND',
                        value: obj[i]
                    })
                }
            }
            data.querys = [...data.querys, ...querys]
            data.pageBean.page = page
            this.pageResult.page = page
            apiList.gteBaseInfo(data, res => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
            })
        },
        handleCurrentChange(page) {
            this.params.pageBean = { ...this.params.pageBean, page }
            this.handleSearch(page)
        },
        handleSizeChange(pageSize) {
            this.params.pageBean = { ...this.params.pageBean, pageSize }
            this.handleSearch(1)
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map(item => item.id)
            this.deleteIds = arr.join(',')
        },
        //删除
        handleDelete() {
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'error'
            }).then(() => {
                this.markLoading = true
                // apiList.deleteDataById(this.deleteIds, res => {
                //     if (res.state) {
                //         this.handleSearch(1)
                //         this.$message.success('删除成功')
                //         this.markLoading = false
                //     } else {
                //         this.markLoading = false
                //     }
                // })
            })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__body {
    height: 65vh;
}

@import '~@/assets/css/element-variables.scss';

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/ .el-collapse-item__content {
    padding-bottom: 5px;
}

.fs-input {
    /deep/ .el-input__inner {
        height: 29px;
        line-height: 18px;
        text-align: center;
    }
}

.upload_file {
    opacity: 1;
    height: 100%;
    pointer-events: auto;
    // transition: all 0.3s;
}

.upload_file_none {
    opacity: 0;
    height: 0;
    pointer-events: none;
    // transition: all 0.3s;
}

/deep/ .el-upload--picture-card {
    display: block;
    border: none;
    width: 100%;
    height: 70px;
    line-height: 70px;
    text-align: left;
}

/deep/.el-upload-list--picture-card .el-upload-list__item {
    width: 100px;
    height: 70px;
}

/deep/ .upload-demo {
    display: flex;
    flex-direction: column-reverse;
    pointer-events: auto;

    > {
        flex: 1;
    }
}

/deep/ .btn-show {
    .el-upload--picture-card {
        height: 0 !important;
        width: 0;
        opacity: 0;
        pointer-events: none;
    }
}

/deep/.el-descriptions__header {
    margin: 15px 0 0 0;

    .el-descriptions__title {
        font-weight: normal;
    }
}

.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 5px 3px 5px;
    padding-right: 5px;
    border-radius: 2px;

    a {
        margin-right: 8px;
        user-select: none;
    }
}

.file-item:hover {
    background-color: #f5f5f5;
}

/deep/.el-input__inner::-webkit-outer-spin-button,
/deep/.el-input__inner::-webkit-inner-spin-button {
    -webkit-appearance: none;
}

.satisfaction {
    /deep/.el-table__row {
        .el-table__cell {
            .cell {
                height: 100% !important;
                line-height: 50px !important;
            }
        }
    }
}

/deep/ .el-table th.el-table__cell>.cell {
    white-space: pre;
}

// 导入居中
.import-demo {
    text-align: center;
}
</style>
